package com.findme;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import android.content.Context;
import android.content.SharedPreferences;
import android.graphics.drawable.Drawable;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.util.Log;

import com.findme.beans.User;
import com.findme.utils.Alerta;
import com.findme.utils.SoapCall;
import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;
import com.google.android.maps.Overlay;
import com.google.android.maps.OverlayItem;


public class HomeMapActivity extends FindMeMapActivity {
	
	private LocationManager lm;
    private LocationListener locationListener;

    private MapView mapView;
    private MapController mc;
    
    protected boolean isRouteDisplayed() {
	    return false;
	}
	
	public void onCreate(Bundle savedInstanceState) {
	    super.onCreate(savedInstanceState);
	    setContentView(R.layout.map);
	    
	    //Busquem la localització de l'usuari al mapa
	    Bundle extras = getIntent().getExtras();
	    User usuari = (User) extras.getSerializable("usuari");
	    boolean search = extras.getBoolean("search");
	    buscaPosicio(usuari, search);
	    
	    //Si el punt que visualitzem es el del super usuari activem la geolocalització
	    User super_user = ((FindMeApp) this.getApplication()).getUsuario();
        if(usuari.getId() == super_user.getId()) {

        	//Usem LocationManager per obtenir la localització GPS
	        lm = (LocationManager) getSystemService(Context.LOCATION_SERVICE);    
	     
	        locationListener = new MyLocationListener();
	        
	        lm.requestLocationUpdates(LocationManager.GPS_PROVIDER,0,0,locationListener);
	        
	        mapView = (MapView) findViewById(R.id.mapview);
	        mc = mapView.getController();
        }
	    
	}
	
	protected boolean guarda(int l1, int l2) {
		String[][] matriz={{"session_id", ((FindMeApp) this.getApplication()).getSessionId()},{"longitud", String.valueOf(l1)},{"latitud", String.valueOf(l2)}};
		try {
			SoapCall.requestJson("updateLocation", matriz);
			
		} catch (Exception e) {
			// TODO Auto-generated catch block
			Log.i("AKI",matriz.toString());
			e.printStackTrace();
			
		}
		return false;
    }
	
	private void buscaPosicio(User usuari, boolean search) {
		int idUser = usuari.getId();
	    String name = usuari.getName();
	    SimpleDateFormat format = new SimpleDateFormat("d/M/y");
	    Date now = new Date();
        String email = " Last seen:"+format.format(now) + " Email:"+usuari.getEmail();
        int latitud = Integer.valueOf(usuari.getLatitud());
        int longitud = Integer.valueOf(usuari.getLongitud());
        
        MapView mapView = (MapView) findViewById(R.id.mapview);
        mapView.setBuiltInZoomControls(true); 
        
        List<Overlay> mapOverlays = mapView.getOverlays();
        Drawable drawable;
        if(usuari.isFriend()) {
        	drawable = this.getResources().getDrawable(R.drawable.pin2);
        } else {
        	drawable = this.getResources().getDrawable(R.drawable.pin);
        }
        
		GeoPoint point = new GeoPoint(longitud,latitud);
        mapView.getController().animateTo(point);
        //mapView.getController().setZoom(15);
        
        SharedPreferences _sharedPreferences  = PreferenceManager.getDefaultSharedPreferences(getBaseContext());
        String view = _sharedPreferences.getString("vista_mapa", "streetview");
        
        if (view.equals("streetview")) {
        	mapView.setStreetView(true);
        	mapView.setSatellite(false); 
        } else {
        	mapView.setStreetView(false);
        	mapView.setSatellite(true);
        }
        
        if(search) {
        	OverlayItem overlayitem = new OverlayItem(point, name, String.valueOf(idUser));
        	MyItemizedOverlay2 itemizedoverlay = new MyItemizedOverlay2(drawable, this);
        	itemizedoverlay.addOverlay(overlayitem);
        	mapOverlays.add(itemizedoverlay);
        } else {
        	OverlayItem overlayitem = new OverlayItem(point, name, email);
        	MyItemizedOverlay itemizedoverlay = new MyItemizedOverlay(drawable, this);
        	itemizedoverlay.addOverlay(overlayitem);
        	mapOverlays.add(itemizedoverlay);
        }
	}

	private class MyLocationListener implements LocationListener {

        public void onLocationChanged(Location loc) {
            if (loc != null) {
            	locChange(loc);
            }
        }

        public void onProviderDisabled(String provider) {
            // TODO Auto-generated method stub
        }

        public void onProviderEnabled(String provider) {
            // TODO Auto-generated method stub
        }

        public void onStatusChanged(String provider, int status, 
            Bundle extras) {
            // TODO Auto-generated method stub
        }
    }

	public void locChange(Location loc) {
		Alerta.toast(getBaseContext(), "Location changed : Lat: " + loc.getLatitude() + " Lng: " + loc.getLongitude());
    	//Actualitzem la posició
		int l1 = (int)(loc.getLatitude() * 1000000);
    	int l2 = (int)(loc.getLongitude() * 1000000);
    	//Actualitzem la BD
    	User super_user = ((FindMeApp) this.getApplication()).getUsuario();
    	if(super_user.getAutolocation()) {
    		guarda(l2,l1);
    	}
        //Actualitzem l'usuari
        User usuari = ((FindMeApp) this.getApplication()).getUsuario();
        usuari.setLatitud(l1);
        usuari.setLongitud(l2);
        ((FindMeApp) this.getApplication()).setUsuario(usuari);
        buscaPosicio(usuari, false);
        //Mostrem el punt al mapa
        /*GeoPoint p = new GeoPoint(
                (int) (loc.getLatitude() * 1E6), 
                (int) (loc.getLongitude() * 1E6));
        mc.animateTo(p);
        mc.setZoom(16);                
        mapView.invalidate();*/
	}
}